@@ -3,7 +3,7 @@
  *                Daniel R. Reynolds @ SMU
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2023, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -19,15 +19,13 @@
 #ifndef _SIMPLEPARGRID_H
 #define _SIMPLEPARGRID_H
 
+#include <fstream>
 #include <iomanip>
 #include <iostream>
-#include <fstream>
 #include <mpi.h>
-
 #include <sundials/sundials_memory.h>
 
-namespace sundials_tools
-{
+namespace sundials_tools {
 
 // Types of boundaries supported.
 enum class BoundaryType
@@ -57,18 +55,34 @@ public:
   // [in] width - the stencil width; defaults to 1
   // [in] npxyz - the number of processors in each dimension; defaults to 0 which means MPI will choose
   // [in] reorder - should MPI_Cart_create do process reordering to optimize or not; defaults to false (some MPI implementations ignore this)
-  ParallelGrid(SUNMemoryHelper memhelp, MPI_Comm* comm, const REAL a[], const REAL b[],
-               const GLOBALINT npts[], int dof, BoundaryType bc, StencilType st,
-               const REAL c, int width = 1, const int npxyz[] = nullptr,
-               bool reorder = false)
-    : nx(1), ny(1), nz(1),
-      nxl(1), nyl(1), nzl(1),
-      npx(1), npy(1), npz(1),
-      dx(0.0), dy(0.0), dz(0.0),
-      ax(0.0), ay(0.0), az(0.0),
-      bx(0.0), by(0.0), bz(0.0),
-      dof(dof), dims{0,0,0}, coords{0,0,0},
-      bc(bc), st(st), width(width),
+  ParallelGrid(SUNMemoryHelper memhelp, MPI_Comm* comm, const REAL a[],
+               const REAL b[], const GLOBALINT npts[], int dof, BoundaryType bc,
+               StencilType st, const REAL c, int width = 1,
+               const int npxyz[] = nullptr, bool reorder = false)
+    : nx(1),
+      ny(1),
+      nz(1),
+      nxl(1),
+      nyl(1),
+      nzl(1),
+      npx(1),
+      npy(1),
+      npz(1),
+      dx(0.0),
+      dy(0.0),
+      dz(0.0),
+      ax(0.0),
+      ay(0.0),
+      az(0.0),
+      bx(0.0),
+      by(0.0),
+      bz(0.0),
+      dof(dof),
+      dims{0, 0, 0},
+      coords{0, 0, 0},
+      bc(bc),
+      st(st),
+      width(width),
       upwindRight(true),
       memhelp(memhelp)
 
@@ -88,10 +102,9 @@ public:
     retval = MPI_Dims_create(nprocs, 3, dims);
     assert(retval == MPI_SUCCESS);
 
-    int periods[] = { bc == BoundaryType::PERIODIC,
-                      bc == BoundaryType::PERIODIC,
-                      bc == BoundaryType::PERIODIC };
-    retval = MPI_Cart_create(*comm, 3, dims, periods, reorder, comm);
+    int periods[] = {bc == BoundaryType::PERIODIC, bc == BoundaryType::PERIODIC,
+                     bc == BoundaryType::PERIODIC};
+    retval        = MPI_Cart_create(*comm, 3, dims, periods, reorder, comm);
     assert(retval == MPI_SUCCESS);
 
     retval = MPI_Cart_get(*comm, 3, dims, periods, coords);
@@ -103,42 +116,40 @@ public:
     upwindRight = (c > 0.0);
 
     /* Set up information for the first spatial dimension */
-    npx = dims[0];
-    nx  = npts[0];
-    ax  = a[0];
-    bx  = b[0];
-    dx  = (bx-ax) / (REAL) nx;
-    int is = nx*(coords[0])/npx;
-    int ie = nx*(coords[0]+1)/npx-1;
-    nxl = ie-is+1;
-    neq = dof * nxl;
+    npx    = dims[0];
+    nx     = npts[0];
+    ax     = a[0];
+    bx     = b[0];
+    dx     = (bx - ax) / (REAL)nx;
+    int is = nx * (coords[0]) / npx;
+    int ie = nx * (coords[0] + 1) / npx - 1;
+    nxl    = ie - is + 1;
+    neq    = dof * nxl;
 
     /* Set up information for the second spatial dimension */
-    npy = dims[1];
-    ny  = npts[1];
-    ay  = a[1];
-    by  = b[1];
-    dy  = (by-ay) / (REAL) ny;
-    int js = ny*(coords[1])/npy;
-    int je = ny*(coords[1]+1)/npy-1;
-    nyl = je-js+1;
+    npy    = dims[1];
+    ny     = npts[1];
+    ay     = a[1];
+    by     = b[1];
+    dy     = (by - ay) / (REAL)ny;
+    int js = ny * (coords[1]) / npy;
+    int je = ny * (coords[1] + 1) / npy - 1;
+    nyl    = je - js + 1;
     neq *= nyl;
 
     /* Set up information for the third spatial dimension */
-    npz = dims[2];
-    nz  = npts[2];
-    az  = a[2];
-    bz  = b[2];
-    dz  = (bz-az) / (REAL) nz;
-    int ks = nz*(coords[2])/npz;
-    int ke = nz*(coords[2]+1)/npz-1;
-    nzl = ke-ks+1;
+    npz    = dims[2];
+    nz     = npts[2];
+    az     = a[2];
+    bz     = b[2];
+    dz     = (bz - az) / (REAL)nz;
+    int ks = nz * (coords[2]) / npz;
+    int ke = nz * (coords[2] + 1) / npz - 1;
+    nzl    = ke - ks + 1;
     neq *= nzl;
 
     /* Allocate buffers for nearest-neighbor exchange */
-    if (st == StencilType::UPWIND)
-      AllocateBuffersUpwind();
-
+    if (st == StencilType::UPWIND) { AllocateBuffersUpwind(); }
   }
 
   // TODO:
@@ -147,148 +158,187 @@ public:
   // For all faces: allocate exchange buffers.
   void AllocateBuffersUpwind()
   {
-
     /* Allocate send/receive buffers and determine ID for communication West */
     if (upwindRight)
-      SUNMemoryHelper_Alloc(memhelp, &Wrecv_, sizeof(REAL)*dof*width*nyl*nzl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Wrecv_,
+                            sizeof(REAL) * dof * width * nyl * nzl,
                             memoryType(), nullptr);
+    }
     else
-      SUNMemoryHelper_Alloc(memhelp, &Wsend_, sizeof(REAL)*dof*width*nyl*nzl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Wsend_,
+                            sizeof(REAL) * dof * width * nyl * nzl,
                             memoryType(), nullptr);
+    }
     ipW = MPI_PROC_NULL;
-    if ((coords[0] > 0) || (bc == BoundaryType::PERIODIC)) {
-      int nbcoords[] = {coords[0]-1, coords[1], coords[2]};
-      int retval = MPI_Cart_rank(cart_comm, nbcoords, &ipW);
+    if ((coords[0] > 0) || (bc == BoundaryType::PERIODIC))
+    {
+      int nbcoords[] = {coords[0] - 1, coords[1], coords[2]};
+      int retval     = MPI_Cart_rank(cart_comm, nbcoords, &ipW);
       assert(retval == MPI_SUCCESS);
     }
 
     /* Allocate send/receive buffers and determine ID for communication East */
     if (upwindRight)
-      SUNMemoryHelper_Alloc(memhelp, &Esend_, sizeof(REAL)*dof*width*nyl*nzl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Esend_,
+                            sizeof(REAL) * dof * width * nyl * nzl,
                             memoryType(), nullptr);
+    }
     else
-      SUNMemoryHelper_Alloc(memhelp, &Erecv_, sizeof(REAL)*dof*width*nyl*nzl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Erecv_,
+                            sizeof(REAL) * dof * width * nyl * nzl,
                             memoryType(), nullptr);
+    }
     ipE = MPI_PROC_NULL;
-    if ((coords[0] < dims[0]-1) || (bc == BoundaryType::PERIODIC)) {
-      int nbcoords[] = {coords[0]+1, coords[1], coords[2]};
-      int retval = MPI_Cart_rank(cart_comm, nbcoords, &ipE);
+    if ((coords[0] < dims[0] - 1) || (bc == BoundaryType::PERIODIC))
+    {
+      int nbcoords[] = {coords[0] + 1, coords[1], coords[2]};
+      int retval     = MPI_Cart_rank(cart_comm, nbcoords, &ipE);
       assert(retval == MPI_SUCCESS);
     }
 
     /* Allocate send/receive buffers and determine ID for communication South */
     if (upwindRight)
-      SUNMemoryHelper_Alloc(memhelp, &Srecv_, sizeof(REAL)*dof*width*nxl*nzl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Srecv_,
+                            sizeof(REAL) * dof * width * nxl * nzl,
                             memoryType(), nullptr);
+    }
     else
-      SUNMemoryHelper_Alloc(memhelp, &Ssend_, sizeof(REAL)*dof*width*nxl*nzl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Ssend_,
+                            sizeof(REAL) * dof * width * nxl * nzl,
                             memoryType(), nullptr);
+    }
     ipS = MPI_PROC_NULL;
-    if ((coords[1] > 0) || (bc == BoundaryType::PERIODIC)) {
-      int nbcoords[] = {coords[0], coords[1]-1, coords[2]};
-      int retval = MPI_Cart_rank(cart_comm, nbcoords, &ipS);
+    if ((coords[1] > 0) || (bc == BoundaryType::PERIODIC))
+    {
+      int nbcoords[] = {coords[0], coords[1] - 1, coords[2]};
+      int retval     = MPI_Cart_rank(cart_comm, nbcoords, &ipS);
       assert(retval == MPI_SUCCESS);
     }
 
     /* Allocate send/receive buffers and determine ID for communication North */
     if (upwindRight)
-      SUNMemoryHelper_Alloc(memhelp, &Nsend_, sizeof(REAL)*dof*width*nxl*nzl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Nsend_,
+                            sizeof(REAL) * dof * width * nxl * nzl,
                             memoryType(), nullptr);
+    }
     else
-      SUNMemoryHelper_Alloc(memhelp, &Nrecv_, sizeof(REAL)*dof*width*nxl*nzl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Nrecv_,
+                            sizeof(REAL) * dof * width * nxl * nzl,
                             memoryType(), nullptr);
+    }
     ipN = MPI_PROC_NULL;
-    if ((coords[1] < dims[1]-1) || (bc == BoundaryType::PERIODIC)) {
-      int nbcoords[] = {coords[0], coords[1]+1, coords[2]};
-      int retval = MPI_Cart_rank(cart_comm, nbcoords, &ipN);
+    if ((coords[1] < dims[1] - 1) || (bc == BoundaryType::PERIODIC))
+    {
+      int nbcoords[] = {coords[0], coords[1] + 1, coords[2]};
+      int retval     = MPI_Cart_rank(cart_comm, nbcoords, &ipN);
       assert(retval == MPI_SUCCESS);
     }
 
     /* Allocate send/receive buffers and determine ID for communication Back */
     if (upwindRight)
-      SUNMemoryHelper_Alloc(memhelp, &Brecv_, sizeof(REAL)*dof*width*nxl*nyl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Brecv_,
+                            sizeof(REAL) * dof * width * nxl * nyl,
                             memoryType(), nullptr);
+    }
     else
-      SUNMemoryHelper_Alloc(memhelp, &Bsend_, sizeof(REAL)*dof*width*nxl*nyl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Bsend_,
+                            sizeof(REAL) * dof * width * nxl * nyl,
                             memoryType(), nullptr);
+    }
     ipB = MPI_PROC_NULL;
-    if ((coords[2] > 0) || (bc == BoundaryType::PERIODIC)) {
-      int nbcoords[] = {coords[0], coords[1], coords[2]-1};
-      int retval = MPI_Cart_rank(cart_comm, nbcoords, &ipB);
+    if ((coords[2] > 0) || (bc == BoundaryType::PERIODIC))
+    {
+      int nbcoords[] = {coords[0], coords[1], coords[2] - 1};
+      int retval     = MPI_Cart_rank(cart_comm, nbcoords, &ipB);
       assert(retval == MPI_SUCCESS);
     }
 
     /* Allocate send/receive buffers and determine ID for communication Front */
     if (upwindRight)
-      SUNMemoryHelper_Alloc(memhelp, &Fsend_, sizeof(REAL)*dof*width*nxl*nyl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Fsend_,
+                            sizeof(REAL) * dof * width * nxl * nyl,
                             memoryType(), nullptr);
+    }
     else
-      SUNMemoryHelper_Alloc(memhelp, &Frecv_, sizeof(REAL)*dof*width*nxl*nyl,
+    {
+      SUNMemoryHelper_Alloc(memhelp, &Frecv_,
+                            sizeof(REAL) * dof * width * nxl * nyl,
                             memoryType(), nullptr);
+    }
     ipF = MPI_PROC_NULL;
-    if ((coords[2] < dims[2]-1) || (bc == BoundaryType::PERIODIC)) {
-      int nbcoords[] = {coords[0], coords[1], coords[2]+1};
-      int retval = MPI_Cart_rank(cart_comm, nbcoords, &ipF);
+    if ((coords[2] < dims[2] - 1) || (bc == BoundaryType::PERIODIC))
+    {
+      int nbcoords[] = {coords[0], coords[1], coords[2] + 1};
+      int retval     = MPI_Cart_rank(cart_comm, nbcoords, &ipF);
       assert(retval == MPI_SUCCESS);
     }
-
   }
 
   // Initiate non-blocking neighbor communication
   int ExchangeStart()
   {
     int retval = 0;
-    nreq = 0;
+    nreq       = 0;
 
     // Initialize all requests in array
-    for (int i=0; i<12; i++)
-      req[i] = MPI_REQUEST_NULL;
+    for (int i = 0; i < 12; i++) { req[i] = MPI_REQUEST_NULL; }
 
     // Open an Irecv buffer for each neighbor
     if ((ipW != MPI_PROC_NULL) && (upwindRight))
     {
-      retval = MPI_Irecv(getRecvBuffer("WEST"), dof*nyl*nzl, MPI_SUNREALTYPE, ipW,
-                         1, cart_comm, req+nreq);
+      retval = MPI_Irecv(getRecvBuffer("WEST"), dof * nyl * nzl,
+                         MPI_SUNREALTYPE, ipW, 1, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
 
     if ((ipE != MPI_PROC_NULL) && (!upwindRight))
     {
-      retval = MPI_Irecv(getRecvBuffer("EAST"), dof*nyl*nzl, MPI_SUNREALTYPE, ipE,
-                         0, cart_comm, req+nreq);
+      retval = MPI_Irecv(getRecvBuffer("EAST"), dof * nyl * nzl,
+                         MPI_SUNREALTYPE, ipE, 0, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
 
     if ((ipS != MPI_PROC_NULL) && (upwindRight))
     {
-      retval = MPI_Irecv(getRecvBuffer("SOUTH"), dof*nxl*nzl, MPI_SUNREALTYPE, ipS,
-                         3, cart_comm, req+nreq);
+      retval = MPI_Irecv(getRecvBuffer("SOUTH"), dof * nxl * nzl,
+                         MPI_SUNREALTYPE, ipS, 3, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
 
     if ((ipN != MPI_PROC_NULL) && (!upwindRight))
     {
-      retval = MPI_Irecv(getRecvBuffer("NORTH"), dof*nxl*nzl, MPI_SUNREALTYPE, ipN,
-                         2, cart_comm, req+nreq);
+      retval = MPI_Irecv(getRecvBuffer("NORTH"), dof * nxl * nzl,
+                         MPI_SUNREALTYPE, ipN, 2, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
 
     if ((ipB != MPI_PROC_NULL) && (upwindRight))
     {
-      retval = MPI_Irecv(getRecvBuffer("BACK"), dof*nxl*nyl, MPI_SUNREALTYPE, ipB,
-                         5, cart_comm, req+nreq);
+      retval = MPI_Irecv(getRecvBuffer("BACK"), dof * nxl * nyl,
+                         MPI_SUNREALTYPE, ipB, 5, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
 
     if ((ipF != MPI_PROC_NULL) && (!upwindRight))
     {
-      retval = MPI_Irecv(getRecvBuffer("FRONT"), dof*nxl*nyl, MPI_SUNREALTYPE, ipF,
-                         4, cart_comm, req+nreq);
+      retval = MPI_Irecv(getRecvBuffer("FRONT"), dof * nxl * nyl,
+                         MPI_SUNREALTYPE, ipF, 4, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
@@ -296,48 +346,48 @@ public:
     // Send data to neighbors
     if ((ipW != MPI_PROC_NULL) && (!upwindRight))
     {
-      retval = MPI_Isend(getSendBuffer("WEST"), dof*nyl*nzl, MPI_SUNREALTYPE, ipW, 0,
-                         cart_comm, req+nreq);
+      retval = MPI_Isend(getSendBuffer("WEST"), dof * nyl * nzl,
+                         MPI_SUNREALTYPE, ipW, 0, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
 
     if ((ipE != MPI_PROC_NULL) && (upwindRight))
     {
-      retval = MPI_Isend(getSendBuffer("EAST"), dof*nyl*nzl, MPI_SUNREALTYPE, ipE, 1,
-                         cart_comm, req+nreq);
+      retval = MPI_Isend(getSendBuffer("EAST"), dof * nyl * nzl,
+                         MPI_SUNREALTYPE, ipE, 1, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
 
     if ((ipS != MPI_PROC_NULL) && (!upwindRight))
     {
-      retval = MPI_Isend(getSendBuffer("SOUTH"), dof*nxl*nzl, MPI_SUNREALTYPE, ipS, 2,
-                         cart_comm, req+nreq);
+      retval = MPI_Isend(getSendBuffer("SOUTH"), dof * nxl * nzl,
+                         MPI_SUNREALTYPE, ipS, 2, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
 
     if ((ipN != MPI_PROC_NULL) && (upwindRight))
     {
-      retval = MPI_Isend(getSendBuffer("NORTH"), dof*nxl*nzl, MPI_SUNREALTYPE, ipN, 3,
-                         cart_comm, req+nreq);
+      retval = MPI_Isend(getSendBuffer("NORTH"), dof * nxl * nzl,
+                         MPI_SUNREALTYPE, ipN, 3, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
 
     if ((ipB != MPI_PROC_NULL) && (!upwindRight))
     {
-      retval = MPI_Isend(getSendBuffer("BACK"), dof*nxl*nyl, MPI_SUNREALTYPE, ipB, 4,
-                         cart_comm, req+nreq);
+      retval = MPI_Isend(getSendBuffer("BACK"), dof * nxl * nyl,
+                         MPI_SUNREALTYPE, ipB, 4, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
 
     if ((ipF != MPI_PROC_NULL) && (upwindRight))
     {
-      retval = MPI_Isend(getSendBuffer("FRONT"), dof*nxl*nyl, MPI_SUNREALTYPE, ipF, 5,
-                         cart_comm, req+nreq);
+      retval = MPI_Isend(getSendBuffer("FRONT"), dof * nxl * nyl,
+                         MPI_SUNREALTYPE, ipF, 5, cart_comm, req + nreq);
       assert(retval == MPI_SUCCESS);
       nreq++;
     }
@@ -352,8 +402,7 @@ public:
     int retval;
 
     // return automatically with success if there are no outstanding requests
-    if (nreq == 0)
-      return(0);
+    if (nreq == 0) { return (0); }
 
     // Wait for messages to finish send/receive
     retval = MPI_Waitall(nreq, req, stat);
@@ -368,14 +417,14 @@ public:
     printf("ParallelGrid Info:\n");
     printf("    dimensions = %d\n", 3);
     printf("    processors = {%d, %d, %d}\n", npx, npy, npz);
-    printf("        domain = {[%g,%g], [%g,%g], [%g,%g]}\n", ax, bx, ay, by, az, bz);
-    printf("   global npts = {%li, %li, %li}\n", (long int) nx, (long int) ny, (long int) nz);
+    printf("        domain = {[%g,%g], [%g,%g], [%g,%g]}\n", ax, bx, ay, by, az,
+           bz);
+    printf("   global npts = {%li, %li, %li}\n", (long int)nx, (long int)ny,
+           (long int)nz);
     printf("    local npts = {%d, %d, %d}\n", nxl, nyl, nzl);
     printf("  mesh spacing = {%g, %g, %g}\n", dx, dy, dz);
-    if (upwindRight)
-      printf("    upwind dir = right\n");
-    else
-      printf("    upwind dir = left\n");
+    if (upwindRight) { printf("    upwind dir = right\n"); }
+    else { printf("    upwind dir = left\n"); }
   }
 
   // Saves the mesh to a file.
@@ -388,64 +437,31 @@ public:
     std::ofstream mesh_file;
     mesh_file.open(fname);
     mesh_file << std::setprecision(16);
-    for (GLOBALINT i = 0; i < nx; i++)
-      mesh_file << " " << dx*i;
+    for (GLOBALINT i = 0; i < nx; i++) { mesh_file << " " << dx * i; }
     mesh_file << std::endl;
-    for (GLOBALINT i = 0; i < ny; i++)
-      mesh_file << " " << dy*i;
+    for (GLOBALINT i = 0; i < ny; i++) { mesh_file << " " << dy * i; }
     mesh_file << std::endl;
-    for (GLOBALINT i = 0; i < nz; i++)
-      mesh_file << " " << dz*i;
+    for (GLOBALINT i = 0; i < nz; i++) { mesh_file << " " << dz * i; }
     mesh_file << std::endl;
     mesh_file.close();
   }
 
-  int nprocs() const
-  {
-    return npx*npy*npz;
-  }
+  int nprocs() const { return npx * npy * npz; }
 
-  GLOBALINT npts() const
-  {
-    return nx*ny*nz;
-  }
+  GLOBALINT npts() const { return nx * ny * nz; }
 
-  GLOBALINT nptsl() const
-  {
-    return nxl*nyl*nzl;
-  }
+  GLOBALINT nptsl() const { return nxl * nyl * nzl; }
 
-  GLOBALINT neql() const
-  {
-    return dof*nptsl();
-  }
+  GLOBALINT neql() const { return dof * nptsl(); }
 
   REAL* getRecvBuffer(const std::string& direction)
   {
-    if (direction == "WEST")
-    {
-      return static_cast<REAL*>(Wrecv_->ptr);
-    }
-    else if (direction == "EAST")
-    {
-      return static_cast<REAL*>(Erecv_->ptr);
-    }
-    else if (direction == "NORTH")
-    {
-      return static_cast<REAL*>(Nrecv_->ptr);
-    }
-    else if (direction == "SOUTH")
-    {
-      return static_cast<REAL*>(Srecv_->ptr);
-    }
-    else if (direction == "FRONT")
-    {
-      return static_cast<REAL*>(Frecv_->ptr);
-    }
-    else if (direction == "BACK")
-    {
-      return static_cast<REAL*>(Brecv_->ptr);
-    }
+    if (direction == "WEST") { return static_cast<REAL*>(Wrecv_->ptr); }
+    else if (direction == "EAST") { return static_cast<REAL*>(Erecv_->ptr); }
+    else if (direction == "NORTH") { return static_cast<REAL*>(Nrecv_->ptr); }
+    else if (direction == "SOUTH") { return static_cast<REAL*>(Srecv_->ptr); }
+    else if (direction == "FRONT") { return static_cast<REAL*>(Frecv_->ptr); }
+    else if (direction == "BACK") { return static_cast<REAL*>(Brecv_->ptr); }
     else
     {
       assert(direction == "ILLEGAL");
@@ -455,30 +471,12 @@ public:
 
   REAL* getSendBuffer(const std::string& direction)
   {
-    if (direction == "WEST")
-    {
-      return static_cast<REAL*>(Wsend_->ptr);
-    }
-    else if (direction == "EAST")
-    {
-      return static_cast<REAL*>(Esend_->ptr);
-    }
-    else if (direction == "NORTH")
-    {
-      return static_cast<REAL*>(Nsend_->ptr);
-    }
-    else if (direction == "SOUTH")
-    {
-      return static_cast<REAL*>(Ssend_->ptr);
-    }
-    else if (direction == "FRONT")
-    {
-      return static_cast<REAL*>(Fsend_->ptr);
-    }
-    else if (direction == "BACK")
-    {
-      return static_cast<REAL*>(Bsend_->ptr);
-    }
+    if (direction == "WEST") { return static_cast<REAL*>(Wsend_->ptr); }
+    else if (direction == "EAST") { return static_cast<REAL*>(Esend_->ptr); }
+    else if (direction == "NORTH") { return static_cast<REAL*>(Nsend_->ptr); }
+    else if (direction == "SOUTH") { return static_cast<REAL*>(Ssend_->ptr); }
+    else if (direction == "FRONT") { return static_cast<REAL*>(Fsend_->ptr); }
+    else if (direction == "BACK") { return static_cast<REAL*>(Bsend_->ptr); }
     else
     {
       assert(direction == "ILLEGAL");
@@ -488,14 +486,17 @@ public:
 
   ~ParallelGrid()
   {
-    if (upwindRight) {
+    if (upwindRight)
+    {
       SUNMemoryHelper_Dealloc(memhelp, Esend_, nullptr);
       SUNMemoryHelper_Dealloc(memhelp, Nsend_, nullptr);
       SUNMemoryHelper_Dealloc(memhelp, Fsend_, nullptr);
       SUNMemoryHelper_Dealloc(memhelp, Wrecv_, nullptr);
       SUNMemoryHelper_Dealloc(memhelp, Srecv_, nullptr);
       SUNMemoryHelper_Dealloc(memhelp, Brecv_, nullptr);
-    } else {
+    }
+    else
+    {
       SUNMemoryHelper_Dealloc(memhelp, Wsend_, nullptr);
       SUNMemoryHelper_Dealloc(memhelp, Ssend_, nullptr);
       SUNMemoryHelper_Dealloc(memhelp, Bsend_, nullptr);
@@ -505,35 +506,34 @@ public:
     }
   }
 
-  GLOBALINT nx, ny, nz;    /* number of intervals globally       */
-  int       nxl, nyl, nzl; /* number of intervals locally        */
-  int       npx, npy, npz; /* numner of processes                */
-  REAL      dx, dy, dz;    /* mesh spacing                       */
-  REAL      ax, ay, az;    /* domain in [a, b]                   */
-  REAL      bx, by, bz;
-  int       dof;           /* degrees of freedom per node        */
-  int       neq;           /* total number of equations locally  */
+  GLOBALINT nx, ny, nz; /* number of intervals globally       */
+  int nxl, nyl, nzl;    /* number of intervals locally        */
+  int npx, npy, npz;    /* numner of processes                */
+  REAL dx, dy, dz;      /* mesh spacing                       */
+  REAL ax, ay, az;      /* domain in [a, b]                   */
+  REAL bx, by, bz;
+  int dof; /* degrees of freedom per node        */
+  int neq; /* total number of equations locally  */
 
-  int       ipW, ipE;      /* MPI ranks for neighbor procs       */
-  int       ipS, ipN;
-  int       ipB, ipF;
-  bool      upwindRight;   /* Upwind dir: true/false == R/L      */
-
-  int       dims[3];
-  int       coords[3];
+  int ipW, ipE; /* MPI ranks for neighbor procs       */
+  int ipS, ipN;
+  int ipB, ipF;
+  bool upwindRight; /* Upwind dir: true/false == R/L      */
 
+  int dims[3];
+  int coords[3];
 
 private:
-  MPI_Comm     cart_comm;  /* MPI cartesian communicator         */
-  MPI_Request  req[12];
-  int          nreq;
+  MPI_Comm cart_comm; /* MPI cartesian communicator         */
+  MPI_Request req[12];
+  int nreq;
 
   BoundaryType bc;
-  StencilType  st;
-  int          width;
+  StencilType st;
+  int width;
 
   SUNMemoryHelper memhelp;
-  SUNMemory Wsend_;            /* MPI send/recv buffers              */
+  SUNMemory Wsend_; /* MPI send/recv buffers              */
   SUNMemory Esend_;
   SUNMemory Ssend_;
   SUNMemory Nsend_;
@@ -553,28 +553,24 @@ private:
                                nullptr))
     {
       SUNMemoryHelper_Dealloc(memhelp, test, nullptr);
-      return(SUNMEMTYPE_PINNED);
+      return (SUNMEMTYPE_PINNED);
     }
     if (!SUNMemoryHelper_Alloc(memhelp, &test, sizeof(REAL), SUNMEMTYPE_DEVICE,
                                nullptr))
     {
       SUNMemoryHelper_Dealloc(memhelp, test, nullptr);
-      return(SUNMEMTYPE_DEVICE);
+      return (SUNMEMTYPE_DEVICE);
     }
     if (!SUNMemoryHelper_Alloc(memhelp, &test, sizeof(REAL), SUNMEMTYPE_UVM,
                                nullptr))
     {
       SUNMemoryHelper_Dealloc(memhelp, test, nullptr);
-      return(SUNMEMTYPE_UVM);
-    }
-    else
-    {
-      return(SUNMEMTYPE_HOST);
+      return (SUNMEMTYPE_UVM);
     }
+    else { return (SUNMEMTYPE_HOST); }
   }
-
 };
 
-}
+} // namespace sundials_tools
 
 #endif
