@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2023, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -14,37 +14,35 @@
  * ARKODE main for 2D diffusion benchmark problem
  * ---------------------------------------------------------------------------*/
 
-#include "diffusion_2D.hpp"
 #include "arkode/arkode_arkstep.h"
+#include "diffusion_2D.hpp"
 
 struct UserOptions
 {
   // Integrator settings
-  realtype rtol        = RCONST(1.0e-5);   // relative tolerance
-  realtype atol        = RCONST(1.0e-10);  // absolute tolerance
-  realtype hfixed      = ZERO;             // fixed step size
-  int      order       = 3;                // ARKode method order
-  int      controller  = 0;                // step size adaptivity method
-  int      maxsteps    = 0;                // max steps between outputs
-  int      onestep     = 0;                // one step mode, number of steps
-  bool     linear      = true;             // linearly implicit RHS
-  bool     diagnostics = false;            // output diagnostics
+  sunrealtype rtol   = SUN_RCONST(1.0e-5);  // relative tolerance
+  sunrealtype atol   = SUN_RCONST(1.0e-10); // absolute tolerance
+  sunrealtype hfixed = ZERO;                // fixed step size
+  int order          = 3;                   // ARKode method order
+  int controller     = 0;                   // step size adaptivity method
+  int maxsteps       = 0;                   // max steps between outputs
+  int onestep        = 0;                   // one step mode, number of steps
+  bool linear        = true;                // linearly implicit RHS
 
   // Linear solver and preconditioner settings
-  std::string ls              = "cg";   // linear solver to use
-  bool        preconditioning = true;   // preconditioner on/off
-  bool        lsinfo          = false;  // output residual history
-  int         liniters        = 20;     // number of linear iterations
-  int         msbp            = 0;      // preconditioner setup frequency
-  realtype    epslin          = ZERO;   // linear solver tolerance factor
+  std::string ls       = "cg";  // linear solver to use
+  bool preconditioning = true;  // preconditioner on/off
+  bool lsinfo          = false; // output residual history
+  int liniters         = 20;    // number of linear iterations
+  int msbp             = 0;     // preconditioner setup frequency
+  sunrealtype epslin   = ZERO;  // linear solver tolerance factor
 
   // Helper functions
-  int parse_args(vector<string> &args, bool outproc);
+  int parse_args(vector<string>& args, bool outproc);
   void help();
   void print();
 };
 
-
 // -----------------------------------------------------------------------------
 // Main Program
 // -----------------------------------------------------------------------------
@@ -56,18 +54,18 @@ int main(int argc, char* argv[])
 
   // Initialize MPI
   flag = MPI_Init(&argc, &argv);
-  if (check_flag(&flag, "MPI_Init", 1)) return 1;
+  if (check_flag(&flag, "MPI_Init", 1)) { return 1; }
 
   // Create SUNDIALS context
-  MPI_Comm    comm = MPI_COMM_WORLD;
-  SUNContext  ctx  = NULL;
+  MPI_Comm comm    = MPI_COMM_WORLD;
+  SUNContext ctx   = NULL;
   SUNProfiler prof = NULL;
 
-  flag = SUNContext_Create((void*) &comm, &ctx);
-  if (check_flag(&flag, "SUNContextCreate", 1)) return 1;
+  flag = SUNContext_Create(comm, &ctx);
+  if (check_flag(&flag, "SUNContextCreate", 1)) { return 1; }
 
   flag = SUNContext_GetProfiler(ctx, &prof);
-  if (check_flag(&flag, "SUNContext_GetProfiler", 1)) return 1;
+  if (check_flag(&flag, "SUNContext_GetProfiler", 1)) { return 1; }
 
   // Add scope so objects are destroyed before MPI_Finalize
   {
@@ -76,7 +74,7 @@ int main(int argc, char* argv[])
     // MPI process ID
     int myid;
     flag = MPI_Comm_rank(MPI_COMM_WORLD, &myid);
-    if (check_flag(&flag, "MPI_Comm_rank", 1)) return 1;
+    if (check_flag(&flag, "MPI_Comm_rank", 1)) { return 1; }
 
     bool outproc = (myid == 0);
 
@@ -84,20 +82,20 @@ int main(int argc, char* argv[])
     // Parse command line inputs
     // --------------------------
 
-    UserData    udata(prof);
+    UserData udata(prof);
     UserOptions uopts;
-    UserOutput  uout;
+    UserOutput uout;
 
     vector<string> args(argv + 1, argv + argc);
 
     flag = udata.parse_args(args, outproc);
-    if (check_flag(&flag, "UserData::parse_args", 1)) return 1;
+    if (check_flag(&flag, "UserData::parse_args", 1)) { return 1; }
 
     flag = uopts.parse_args(args, outproc);
-    if (check_flag(&flag, "UserOptions::parse_args", 1)) return 1;
+    if (check_flag(&flag, "UserOptions::parse_args", 1)) { return 1; }
 
     flag = uout.parse_args(args, outproc);
-    if (check_flag(&flag, "UserOutput::parse_args", 1)) return 1;
+    if (check_flag(&flag, "UserOutput::parse_args", 1)) { return 1; }
 
     // Check for unparsed inputs
     if (args.size() > 0)
@@ -105,8 +103,7 @@ int main(int argc, char* argv[])
       if (find(args.begin(), args.end(), "--help") == args.end())
       {
         cerr << "ERROR: Unknown inputs: ";
-        for (auto i = args.begin(); i != args.end(); ++i)
-          cerr << *i << ' ';
+        for (auto i = args.begin(); i != args.end(); ++i) { cerr << *i << ' '; }
         cerr << endl;
       }
       return 1;
@@ -117,23 +114,13 @@ int main(int argc, char* argv[])
     // -----------------------------
 
     flag = udata.setup();
-    if (check_flag(&flag, "UserData::setup", 1)) return 1;
-
-    // Output problem setup/options
-    FILE *diagfp = NULL;
+    if (check_flag(&flag, "UserData::setup", 1)) { return 1; }
 
     if (outproc)
     {
       udata.print();
       uopts.print();
       uout.print();
-
-      // Open diagnostics output file
-      if (uopts.diagnostics || uopts.lsinfo)
-      {
-        diagfp = fopen("diagnostics.txt", "w");
-        if (check_flag((void *) diagfp, "fopen", 0)) return 1;
-      }
     }
 
     // ---------------
@@ -144,26 +131,25 @@ int main(int argc, char* argv[])
 #if defined(USE_HIP)
     N_Vector u = N_VMake_MPIPlusX(udata.comm_c,
                                   N_VNew_Hip(udata.nodes_loc, ctx), ctx);
-    if (check_flag((void *) u, "N_VMake_MPIPlusX", 0)) return 1;
+    if (check_flag((void*)u, "N_VMake_MPIPlusX", 0)) return 1;
 #elif defined(USE_CUDA)
     N_Vector u = N_VMake_MPIPlusX(udata.comm_c,
                                   N_VNew_Cuda(udata.nodes_loc, ctx), ctx);
-    if (check_flag((void *) u, "N_VMake_MPIPlusX", 0)) return 1;
+    if (check_flag((void*)u, "N_VMake_MPIPlusX", 0)) return 1;
 #else
-    N_Vector u = N_VNew_Parallel(udata.comm_c, udata.nodes_loc, udata.nodes,
-                                 ctx);
-    if (check_flag((void *) u, "N_VNew_Parallel", 0)) return 1;
+    N_Vector u = N_VNew_Parallel(udata.comm_c, udata.nodes_loc, udata.nodes, ctx);
+    if (check_flag((void*)u, "N_VNew_Parallel", 0)) { return 1; }
 #endif
 
     // Set initial condition
     flag = Solution(ZERO, u, &udata);
-    if (check_flag(&flag, "Solution", 1)) return 1;
+    if (check_flag(&flag, "Solution", 1)) { return 1; }
 
     // Create vector for error
     if (udata.forcing)
     {
       uout.error = N_VClone(u);
-      if (check_flag((void *) (uout.error), "N_VClone", 0)) return 1;
+      if (check_flag((void*)(uout.error), "N_VClone", 0)) { return 1; }
     }
 
     // ---------------------
@@ -172,7 +158,7 @@ int main(int argc, char* argv[])
 
     // Create linear solver
     SUNLinearSolver LS = NULL;
-    SUNMatrix A = nullptr;
+    SUNMatrix A        = nullptr;
 #if defined(USE_SUPERLU_DIST)
     // SuperLU-DIST objects
     SuperMatrix A_super;
@@ -182,40 +168,22 @@ int main(int argc, char* argv[])
     dSOLVEstruct_t A_solve;
     SuperLUStat_t A_stat;
     superlu_dist_options_t A_opts;
-    sunrealtype* A_data = nullptr;
+    sunrealtype* A_data      = nullptr;
     sunindextype* A_col_idxs = nullptr;
     sunindextype* A_row_ptrs = nullptr;
 #endif
 
-    int prectype = (uopts.preconditioning) ? PREC_RIGHT : PREC_NONE;
+    int prectype = (uopts.preconditioning) ? SUN_PREC_RIGHT : SUN_PREC_NONE;
 
     if (uopts.ls == "cg")
     {
       LS = SUNLinSol_PCG(u, prectype, uopts.liniters, ctx);
-      if (check_flag((void *) LS, "SUNLinSol_PCG", 0)) return 1;
-
-      if (uopts.lsinfo && outproc)
-      {
-        flag = SUNLinSolSetPrintLevel_PCG(LS, 1);
-        if (check_flag(&flag, "SUNLinSolSetPrintLevel_PCG", 1)) return(1);
-
-        flag = SUNLinSolSetInfoFile_PCG(LS, diagfp);
-        if (check_flag(&flag, "SUNLinSolSetInfoFile_PCG", 1)) return(1);
-      }
+      if (check_flag((void*)LS, "SUNLinSol_PCG", 0)) { return 1; }
     }
     else if (uopts.ls == "gmres")
     {
       LS = SUNLinSol_SPGMR(u, prectype, uopts.liniters, ctx);
-      if (check_flag((void *) LS, "SUNLinSol_SPGMR", 0)) return 1;
-
-      if (uopts.lsinfo && outproc)
-      {
-        flag = SUNLinSolSetPrintLevel_SPGMR(LS, 1);
-        if (check_flag(&flag, "SUNLinSolSetPrintLevel_SPGMR", 1)) return(1);
-
-        flag = SUNLinSolSetInfoFile_SPGMR(LS, diagfp);
-        if (check_flag(&flag, "SUNLinSolSetInfoFile_SPGMR", 1)) return(1);
-      }
+      if (check_flag((void*)LS, "SUNLinSol_SPGMR", 0)) { return 1; }
     }
     else
     {
@@ -226,20 +194,20 @@ int main(int argc, char* argv[])
       // Create arrays for CSR matrix: data, column indices, and row pointers
       sunindextype nnz_loc = 5 * udata.nodes_loc;
 
-      A_data = (realtype*)malloc(nnz_loc * sizeof(sunrealtype));
+      A_data = (sunrealtype*)malloc(nnz_loc * sizeof(sunrealtype));
       if (check_flag((void*)A_data, "malloc Adata", 0)) return 1;
 
       A_col_idxs = (sunindextype*)malloc(nnz_loc * sizeof(sunindextype));
       if (check_flag((void*)A_col_idxs, "malloc Acolind", 0)) return 1;
 
-      A_row_ptrs = (sunindextype*)malloc((udata.nodes_loc + 1) * sizeof(sunindextype));
+      A_row_ptrs =
+        (sunindextype*)malloc((udata.nodes_loc + 1) * sizeof(sunindextype));
       if (check_flag((void*)A_row_ptrs, "malloc Arowptr", 0)) return 1;
 
       // Create and initialize SuperLU_DIST structures
-      dCreate_CompRowLoc_Matrix_dist(&A_super, udata.nodes, udata.nodes,
-                                     nnz_loc, udata.nodes_loc, 0, A_data,
-                                     A_col_idxs, A_row_ptrs, SLU_NR_loc, SLU_D,
-                                     SLU_GE);
+      dCreate_CompRowLoc_Matrix_dist(&A_super, udata.nodes, udata.nodes, nnz_loc,
+                                     udata.nodes_loc, 0, A_data, A_col_idxs,
+                                     A_row_ptrs, SLU_NR_loc, SLU_D, SLU_GE);
       dScalePermstructInit(udata.nodes, udata.nodes, &A_scaleperm);
       dLUstructInit(udata.nodes, &A_lu);
       PStatInit(&A_stat);
@@ -265,7 +233,7 @@ int main(int argc, char* argv[])
     if (uopts.preconditioning)
     {
       udata.diag = N_VClone(u);
-      if (check_flag((void *) (udata.diag), "N_VClone", 0)) return 1;
+      if (check_flag((void*)(udata.diag), "N_VClone", 0)) { return 1; }
     }
 
     // --------------
@@ -273,20 +241,20 @@ int main(int argc, char* argv[])
     // --------------
 
     // Create integrator
-    void *arkode_mem = ARKStepCreate(NULL, diffusion, ZERO, u, ctx);
-    if (check_flag((void *) arkode_mem, "ARKStepCreate", 0)) return 1;
+    void* arkode_mem = ARKStepCreate(NULL, diffusion, ZERO, u, ctx);
+    if (check_flag((void*)arkode_mem, "ARKStepCreate", 0)) { return 1; }
 
     // Specify tolerances
     flag = ARKStepSStolerances(arkode_mem, uopts.rtol, uopts.atol);
-    if (check_flag(&flag, "ARKStepSStolerances", 1)) return 1;
+    if (check_flag(&flag, "ARKStepSStolerances", 1)) { return 1; }
 
     // Attach user data
-    flag = ARKStepSetUserData(arkode_mem, (void *) &udata);
-    if (check_flag(&flag, "ARKStepSetUserData", 1)) return 1;
+    flag = ARKStepSetUserData(arkode_mem, (void*)&udata);
+    if (check_flag(&flag, "ARKStepSetUserData", 1)) { return 1; }
 
     // Attach linear solver
     flag = ARKStepSetLinearSolver(arkode_mem, LS, A);
-    if (check_flag(&flag, "ARKStepSetLinearSolver", 1)) return 1;
+    if (check_flag(&flag, "ARKStepSetLinearSolver", 1)) { return 1; }
 
 #if defined(USE_SUPERLU_DIST)
     if (uopts.ls == "sludist")
@@ -300,55 +268,48 @@ int main(int argc, char* argv[])
     {
       // Attach preconditioner
       flag = ARKStepSetPreconditioner(arkode_mem, PSetup, PSolve);
-      if (check_flag(&flag, "ARKStepSetPreconditioner", 1)) return 1;
+      if (check_flag(&flag, "ARKStepSetPreconditioner", 1)) { return 1; }
 
       // Set linear solver setup frequency (update preconditioner)
       flag = ARKStepSetLSetupFrequency(arkode_mem, uopts.msbp);
-      if (check_flag(&flag, "ARKStepSetLSetupFrequency", 1)) return 1;
+      if (check_flag(&flag, "ARKStepSetLSetupFrequency", 1)) { return 1; }
     }
 
     // Set linear solver tolerance factor
     flag = ARKStepSetEpsLin(arkode_mem, uopts.epslin);
-    if (check_flag(&flag, "ARKStepSetEpsLin", 1)) return 1;
+    if (check_flag(&flag, "ARKStepSetEpsLin", 1)) { return 1; }
 
     // Select method order
     flag = ARKStepSetOrder(arkode_mem, uopts.order);
-    if (check_flag(&flag, "ARKStepSetOrder", 1)) return 1;
+    if (check_flag(&flag, "ARKStepSetOrder", 1)) { return 1; }
 
     // Set fixed step size or adaptivity method
     if (uopts.hfixed > ZERO)
     {
       flag = ARKStepSetFixedStep(arkode_mem, uopts.hfixed);
-      if (check_flag(&flag, "ARKStepSetFixedStep", 1)) return 1;
+      if (check_flag(&flag, "ARKStepSetFixedStep", 1)) { return 1; }
     }
     else
     {
       flag = ARKStepSetAdaptivityMethod(arkode_mem, uopts.controller, SUNTRUE,
                                         SUNFALSE, NULL);
-      if (check_flag(&flag, "ARKStepSetAdaptivityMethod", 1)) return 1;
+      if (check_flag(&flag, "ARKStepSetAdaptivityMethod", 1)) { return 1; }
     }
 
     // Specify linearly implicit non-time-dependent RHS
     if (uopts.linear)
     {
       flag = ARKStepSetLinear(arkode_mem, 0);
-      if (check_flag(&flag, "ARKStepSetLinear", 1)) return 1;
+      if (check_flag(&flag, "ARKStepSetLinear", 1)) { return 1; }
     }
 
     // Set max steps between outputs
     flag = ARKStepSetMaxNumSteps(arkode_mem, uopts.maxsteps);
-    if (check_flag(&flag, "ARKStepSetMaxNumSteps", 1)) return 1;
+    if (check_flag(&flag, "ARKStepSetMaxNumSteps", 1)) { return 1; }
 
     // Set stopping time
     flag = ARKStepSetStopTime(arkode_mem, udata.tf);
-    if (check_flag(&flag, "ARKStepSetStopTime", 1)) return 1;
-
-    // Set diagnostics output file
-    if (diagfp)
-    {
-      flag = ARKStepSetDiagnostics(arkode_mem, diagfp);
-      if (check_flag(&flag, "ARKStepSetDiagnostics", 1)) return 1;
-    }
+    if (check_flag(&flag, "ARKStepSetStopTime", 1)) { return 1; }
 
     // -----------------------
     // Loop over output times
@@ -364,16 +325,16 @@ int main(int argc, char* argv[])
       stepmode  = ARK_ONE_STEP;
     }
 
-    realtype t     = ZERO;
-    realtype dTout = udata.tf / uout.nout;
-    realtype tout  = dTout;
+    sunrealtype t     = ZERO;
+    sunrealtype dTout = udata.tf / uout.nout;
+    sunrealtype tout  = dTout;
 
     // Inital output
     flag = uout.open(&udata);
-    if (check_flag(&flag, "UserOutput::open", 1)) return 1;
+    if (check_flag(&flag, "UserOutput::open", 1)) { return 1; }
 
     flag = uout.write(t, u, &udata);
-    if (check_flag(&flag, "UserOutput::write", 1)) return 1;
+    if (check_flag(&flag, "UserOutput::write", 1)) { return 1; }
 
     for (int iout = 0; iout < uout.nout; iout++)
     {
@@ -381,13 +342,13 @@ int main(int argc, char* argv[])
 
       // Evolve in time
       flag = ARKStepEvolve(arkode_mem, tout, u, &t, stepmode);
-      if (check_flag(&flag, "ARKStepEvolve", 1)) break;
+      if (check_flag(&flag, "ARKStepEvolve", 1)) { break; }
 
       SUNDIALS_MARK_END(prof, "Evolve");
 
       // Output solution and error
       flag = uout.write(t, u, &udata);
-      if (check_flag(&flag, "UserOutput::write", 1)) return 1;
+      if (check_flag(&flag, "UserOutput::write", 1)) { return 1; }
 
       // Update output time
       tout += dTout;
@@ -396,7 +357,7 @@ int main(int argc, char* argv[])
 
     // Close output
     flag = uout.close(&udata);
-    if (check_flag(&flag, "UserOutput::close", 1)) return 1;
+    if (check_flag(&flag, "UserOutput::close", 1)) { return 1; }
 
     // --------------
     // Final outputs
@@ -407,7 +368,7 @@ int main(int argc, char* argv[])
     {
       cout << "Final integrator statistics:" << endl;
       flag = ARKStepPrintAllStats(arkode_mem, stdout, SUN_OUTPUTFORMAT_TABLE);
-      if (check_flag(&flag, "ARKStepPrintAllStats", 1)) return 1;
+      if (check_flag(&flag, "ARKStepPrintAllStats", 1)) { return 1; }
     }
 
     // ---------
@@ -417,10 +378,6 @@ int main(int argc, char* argv[])
     // Free MPI Cartesian communicator
     MPI_Comm_free(&(udata.comm_c));
 
-    // Close diagnostics output file
-    if (diagfp) fclose(diagfp);
-
-    // Free integrator and linear solver
     ARKStepFree(&arkode_mem);
     SUNLinSolFree(LS);
 
@@ -452,20 +409,18 @@ int main(int argc, char* argv[])
   return 0;
 }
 
-
 // -----------------------------------------------------------------------------
 // UserOptions Helper functions
 // -----------------------------------------------------------------------------
 
-
-int UserOptions::parse_args(vector<string> &args, bool outproc)
+int UserOptions::parse_args(vector<string>& args, bool outproc)
 {
   vector<string>::iterator it;
 
   it = find(args.begin(), args.end(), "--help");
   if (it != args.end())
   {
-    if (outproc) help();
+    if (outproc) { help(); }
     return 0;
   }
 
@@ -525,13 +480,6 @@ int UserOptions::parse_args(vector<string> &args, bool outproc)
     args.erase(it);
   }
 
-  it = find(args.begin(), args.end(), "--diagnostics");
-  if (it != args.end())
-  {
-    diagnostics = true;
-    args.erase(it);
-  }
-
   it = find(args.begin(), args.end(), "--ls");
   if (it != args.end())
   {
@@ -570,7 +518,6 @@ int UserOptions::parse_args(vector<string> &args, bool outproc)
   return 0;
 }
 
-
 // Print command line options
 void UserOptions::help()
 {
@@ -582,7 +529,6 @@ void UserOptions::help()
   cout << "  --order <ord>           : method order" << endl;
   cout << "  --fixedstep <step>      : used fixed step size" << endl;
   cout << "  --controller <ctr>      : time step adaptivity controller" << endl;
-  cout << "  --diagnostics           : output diagnostics" << endl;
   cout << "  --ls <cg|gmres|sludist> : linear solver" << endl;
   cout << "  --lsinfo                : output residual history" << endl;
   cout << "  --liniters <iters>      : max number of iterations" << endl;
@@ -591,21 +537,19 @@ void UserOptions::help()
   cout << "  --msbp <steps>          : max steps between prec setups" << endl;
 }
 
-
 // Print user options
 void UserOptions::print()
 {
   cout << endl;
   cout << " Integrator options:" << endl;
   cout << " --------------------------------- " << endl;
-  cout << " rtol        = " << rtol        << endl;
-  cout << " atol        = " << atol        << endl;
-  cout << " hfixed      = " << hfixed      << endl;
-  cout << " order       = " << order       << endl;
-  cout << " controller  = " << controller  << endl;
-  cout << " max steps   = " << maxsteps    << endl;
-  cout << " linear RHS  = " << linear      << endl;
-  cout << " diagnostics = " << diagnostics << endl;
+  cout << " rtol        = " << rtol << endl;
+  cout << " atol        = " << atol << endl;
+  cout << " hfixed      = " << hfixed << endl;
+  cout << " order       = " << order << endl;
+  cout << " controller  = " << controller << endl;
+  cout << " max steps   = " << maxsteps << endl;
+  cout << " linear RHS  = " << linear << endl;
   cout << " --------------------------------- " << endl;
 
   cout << endl;
@@ -620,20 +564,20 @@ void UserOptions::print()
 #else
     cout << " LS       = SuperLU_DIST" << endl;
 #endif
-    cout << " LS info  = " << lsinfo   << endl;
-    cout << " msbp     = " << msbp     << endl;
+    cout << " LS info  = " << lsinfo << endl;
+    cout << " msbp     = " << msbp << endl;
     cout << " --------------------------------- " << endl;
   }
   else
   {
     cout << " Linear solver options:" << endl;
     cout << " --------------------------------- " << endl;
-    cout << " LS       = " << ls              << endl;
+    cout << " LS       = " << ls << endl;
     cout << " precond  = " << preconditioning << endl;
-    cout << " LS info  = " << lsinfo          << endl;
-    cout << " LS iters = " << liniters        << endl;
-    cout << " msbp     = " << msbp            << endl;
-    cout << " epslin   = " << epslin          << endl;
+    cout << " LS info  = " << lsinfo << endl;
+    cout << " LS iters = " << liniters << endl;
+    cout << " msbp     = " << msbp << endl;
+    cout << " epslin   = " << epslin << endl;
     cout << " --------------------------------- " << endl;
   }
 }
