@@ -25,10 +25,11 @@
 ! than 100 the problem becomes quite stiff.
 ! ------------------------------------------------------------------
 
-module ode_mod
+module analytic_mod
 
   !======= Inclusions ===========
   use, intrinsic :: iso_c_binding
+  use fsundials_core_mod
 
   !======= Declarations =========
   implicit none
@@ -37,7 +38,7 @@ module ode_mod
   integer(c_long), parameter :: neq = 1
 
   ! ODE parameters
-  double precision, parameter :: lamda = -100.0d0
+  real(c_double), parameter :: lamda = -100.0d0
 
 contains
 
@@ -55,20 +56,19 @@ contains
 
     !======= Inclusions ===========
     use, intrinsic :: iso_c_binding
-    use fsundials_nvector_mod
 
     !======= Declarations =========
     implicit none
 
     ! calling variables
-    real(c_double), value :: tn  ! current time
-    type(N_Vector) :: sunvec_y   ! solution N_Vector
-    type(N_Vector) :: sunvec_f   ! rhs N_Vector
-    type(c_ptr) :: user_data     ! user-defined data
+    real(c_double), value :: tn         ! current time
+    type(N_Vector)        :: sunvec_y   ! solution N_Vector
+    type(N_Vector)        :: sunvec_f   ! rhs N_Vector
+    type(c_ptr),    value :: user_data  ! user-defined data
 
     ! pointers to data in SUNDIALS vectors
-    real(c_double), pointer :: yvec(:)
-    real(c_double), pointer :: fvec(:)
+    real(c_double), pointer, dimension(neq) :: yvec(:)
+    real(c_double), pointer, dimension(neq) :: fvec(:)
 
     !======= Internals ============
 
@@ -84,9 +84,15 @@ contains
     return
 
   end function RhsFn
+  ! ----------------------------------------------------------------
 
-end module ode_mod
+end module analytic_mod
+! ------------------------------------------------------------------
 
+
+! ------------------------------------------------------------------
+! Main driver program
+! ------------------------------------------------------------------
 program main
 
   !======= Inclusions ===========
@@ -94,14 +100,11 @@ program main
 
   use farkode_mod                ! Fortran interface to the ARKODE
   use farkode_arkstep_mod        ! Fortran interface to the ARKStep time-stepper module
-  use fsundials_nvector_mod      ! Fortran interface to the generic N_Vector
-  use fsundials_matrix_mod       ! Fortran interface to the generic SUNMatrix
-  use fsundials_linearsolver_mod ! Fortran interface to the generic SUNLinearSolver
   use fnvector_serial_mod        ! Fortran interface to serial N_Vector
   use fsunmatrix_dense_mod       ! Fortran interface to dense SUNMatrix
   use fsunlinsol_dense_mod       ! Fortran interface to dense SUNLinearSolver
-  use fsundials_context_mod      ! Fortran interface to SUNContext
-  use ode_mod                    ! ODE functions
+  use fsunadaptcontroller_soderlind_mod ! Fortran interface to Soderlind controller
+  use analytic_mod               ! ODE functions
 
   !======= Declarations =========
   implicit none
@@ -114,22 +117,21 @@ program main
   real(c_double) :: dtout                    ! output time interval
   real(c_double) :: tout                     ! output time
   real(c_double) :: tcur(1)                  ! current time
-  integer(c_int) :: imethod, idefault, pq    ! time step adaptivity parameters
-  real(c_double) :: adapt_params(3)          ! time step adaptivity parameters
   integer(c_int) :: ierr                     ! error flag from C functions
   integer(c_int) :: nout                     ! number of outputs
   integer(c_int) :: outstep                  ! output loop counter
 
-  type(N_Vector),        pointer :: sunvec_y    ! sundials vector
-  type(SUNMatrix),       pointer :: sunmat_A    ! sundials matrix
-  type(SUNLinearSolver), pointer :: sunls       ! sundials linear solver
-  type(c_ptr)                    :: arkode_mem  ! ARKODE memory
-  real(c_double),        pointer :: yvec(:)     ! underlying vector
+  type(N_Vector),           pointer :: sunvec_y    ! sundials vector
+  type(SUNMatrix),          pointer :: sunmat_A    ! sundials matrix
+  type(SUNLinearSolver),    pointer :: sunls       ! sundials linear solver
+  type(SUNAdaptController), pointer :: sunCtrl     ! time step controller
+  type(c_ptr)                       :: arkode_mem  ! ARKODE memory
+  real(c_double), pointer, dimension(neq) :: yvec(:)  ! underlying vector
 
   !======= Internals ============
 
   ! create the SUNDIALS context
-  ierr = FSUNContext_Create(c_null_ptr, ctx)
+  ierr = FSUNContext_Create(SUN_COMM_NULL, ctx)
 
   ! initialize ODE
   tstart = 0.0d0
@@ -169,8 +171,8 @@ program main
 
   ierr = FARKStepSetLinearSolver(arkode_mem, sunls, sunmat_A)
   if (ierr /= 0) then
-    write(*,*) 'Error in FARKStepSetLinearSolver'
-    stop 1
+     write(*,*) 'Error in FARKStepSetLinearSolver'
+     stop 1
   end if
 
   ! set relative and absolute tolerances
@@ -183,12 +185,20 @@ program main
      stop 1
   end if
 
-  imethod = 4
-  idefault = 1
-  pq = 0
-  ierr = FARKStepSetAdaptivityMethod(arkode_mem, imethod, idefault, pq, adapt_params)
+  sunCtrl => FSUNAdaptController_ImpGus(ctx)
+  if (.not. associated(sunCtrl)) then
+     print *, 'ERROR: sunCtrl = NULL'
+     stop 1
+  end if
+  ierr = FARKStepSetAdaptController(arkode_mem, sunCtrl)
   if (ierr /= 0) then
-     write(*,*) 'Error in FARKStepSetAdaptivityMethod, ierr = ', ierr, '; halting'
+     write(*,*) 'Error in FARKStepSetAdaptController, ierr = ', ierr, '; halting'
+     stop 1
+  end if
+
+  ierr = FARKStepSetNonlinConvCoef(arkode_mem, 0.01d0)
+  if (ierr /= 0) then
+     write(*,*) 'Error in FARKStepSetNonlinConvCoef, ierr = ', ierr, '; halting'
      stop 1
   end if
 
@@ -222,9 +232,11 @@ program main
   call FN_VDestroy(sunvec_y)
   call FSUNMatDestroy(sunmat_A)
   ierr = FSUNLinSolFree(sunls)
+  ierr = FSUNAdaptController_Destroy(sunCtrl)
   ierr = FSUNContext_Free(ctx)
 
 end program main
+! ----------------------------------------------------------------
 
 
 ! ----------------------------------------------------------------
@@ -356,3 +368,4 @@ subroutine ARKStepStats(arkode_mem)
   return
 
 end subroutine ARKStepStats
+! ----------------------------------------------------------------
