@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2021, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -19,28 +19,36 @@
 #include <sundials/sundials_types.h>
 
 /* define constants */
-#define NEG_TWO  RCONST(-2.0)
-#define NEG_ONE  RCONST(-1.0)
-#define NEG_HALF RCONST(-0.5)
-#define ZERO     RCONST(0.0)
-#define HALF     RCONST(0.5)
-#define ONE      RCONST(1.0)
-#define TWO      RCONST(2.0)
+#define NEG_TWO  SUN_RCONST(-2.0)
+#define NEG_ONE  SUN_RCONST(-1.0)
+#define NEG_HALF SUN_RCONST(-0.5)
+#define ZERO     SUN_RCONST(0.0)
+#define HALF     SUN_RCONST(0.5)
+#define ONE      SUN_RCONST(1.0)
+#define TWO      SUN_RCONST(2.0)
 
-#ifdef __cplusplus  /* wrapper to enable C++ usage */
+#ifdef __cplusplus /* wrapper to enable C++ usage */
 extern "C" {
 #endif
 
+extern SUNContext sunctx;
+
 /* Forward declarations for implementation specific utility functions */
-int check_ans(realtype ans, N_Vector X, sunindextype local_length);
-booleantype has_data(N_Vector X);
-void set_element(N_Vector X, sunindextype i, realtype val);
+int check_ans(sunrealtype ans, N_Vector X, sunindextype local_length);
+sunbooleantype has_data(N_Vector X);
+void set_element(N_Vector X, sunindextype i, sunrealtype val);
 void set_element_range(N_Vector X, sunindextype is, sunindextype ie,
-                       realtype val);
-realtype get_element(N_Vector X, sunindextype i);
+                       sunrealtype val);
+sunrealtype get_element(N_Vector X, sunindextype i);
 double max_time(N_Vector X, double time);
 void sync_device(N_Vector X);
 
+/* Shared test initialization/finalization */
+int Test_Init(SUNComm comm);
+int Test_Finalize(void);
+void Test_Abort(int code);
+void Test_AbortMPI(SUNComm comm, int code);
+
 /* Vector ID test */
 int Test_N_VGetVectorID(N_Vector X, N_Vector_ID ID, int myid);
 
@@ -58,8 +66,8 @@ int Test_N_VClone(N_Vector W, sunindextype local_length, int myid);
 int Test_N_VGetArrayPointer(N_Vector W, sunindextype local_length, int myid);
 int Test_N_VSetArrayPointer(N_Vector W, sunindextype local_length, int myid);
 int Test_N_VGetLength(N_Vector W, int myid);
-int Test_N_VGetCommunicator(N_Vector W, void *comm, int myid);
-int Test_N_VGetCommunicatorMPI(N_Vector W, void *comm, int myid);
+int Test_N_VGetCommunicator(N_Vector W, SUNComm comm, int myid);
+int Test_N_VGetCommunicatorMPI(N_Vector W, SUNComm comm, int myid);
 
 /* Standard vector operation tests */
 int Test_N_VLinearSum(N_Vector X, N_Vector Y, N_Vector Z,
@@ -72,23 +80,17 @@ int Test_N_VDiv(N_Vector X, N_Vector Y, N_Vector Z, sunindextype local_length,
 int Test_N_VScale(N_Vector X, N_Vector Z, sunindextype local_length, int myid);
 int Test_N_VAbs(N_Vector X, N_Vector Z, sunindextype local_length, int myid);
 int Test_N_VInv(N_Vector X, N_Vector Z, sunindextype local_length, int myid);
-int Test_N_VAddConst(N_Vector X, N_Vector Z, sunindextype local_length,
-                     int myid);
-int Test_N_VDotProd(N_Vector X, N_Vector Y, sunindextype local_length,
-                    int myid);
+int Test_N_VAddConst(N_Vector X, N_Vector Z, sunindextype local_length, int myid);
+int Test_N_VDotProd(N_Vector X, N_Vector Y, sunindextype local_length, int myid);
 int Test_N_VMaxNorm(N_Vector X, sunindextype local_length, int myid);
-int Test_N_VWrmsNorm(N_Vector X, N_Vector W, sunindextype local_length,
-                     int myid);
+int Test_N_VWrmsNorm(N_Vector X, N_Vector W, sunindextype local_length, int myid);
 int Test_N_VWrmsNormMask(N_Vector X, N_Vector W, N_Vector ID,
                          sunindextype local_length, int myid);
 int Test_N_VMin(N_Vector X, sunindextype local_length, int myid);
-int Test_N_VWL2Norm(N_Vector X, N_Vector W, sunindextype local_length,
-                    int myid);
+int Test_N_VWL2Norm(N_Vector X, N_Vector W, sunindextype local_length, int myid);
 int Test_N_VL1Norm(N_Vector X, sunindextype local_length, int myid);
-int Test_N_VCompare(N_Vector X, N_Vector Z, sunindextype local_length,
-                    int myid);
-int Test_N_VInvTest(N_Vector X, N_Vector Z, sunindextype local_length,
-                    int myid);
+int Test_N_VCompare(N_Vector X, N_Vector Z, sunindextype local_length, int myid);
+int Test_N_VInvTest(N_Vector X, N_Vector Z, sunindextype local_length, int myid);
 int Test_N_VConstrMask(N_Vector C, N_Vector X, N_Vector M,
                        sunindextype local_length, int myid);
 int Test_N_VMinQuotient(N_Vector NUM, N_Vector DENOM, sunindextype local_length,
@@ -100,12 +102,10 @@ int Test_N_VScaleAddMulti(N_Vector X, sunindextype local_length, int myid);
 int Test_N_VDotProdMulti(N_Vector X, sunindextype local_length, int myid);
 
 /* Vector array operation tests */
-int Test_N_VLinearSumVectorArray(N_Vector X, sunindextype local_length,
-                                 int myid);
+int Test_N_VLinearSumVectorArray(N_Vector X, sunindextype local_length, int myid);
 int Test_N_VScaleVectorArray(N_Vector X, sunindextype local_length, int myid);
 int Test_N_VConstVectorArray(N_Vector X, sunindextype local_length, int myid);
-int Test_N_VWrmsNormVectorArray(N_Vector X, sunindextype local_length,
-                                int myid);
+int Test_N_VWrmsNormVectorArray(N_Vector X, sunindextype local_length, int myid);
 int Test_N_VWrmsNormMaskVectorArray(N_Vector X, sunindextype local_length,
                                     int myid);
 int Test_N_VScaleAddMultiVectorArray(N_Vector X, sunindextype local_length,
@@ -130,6 +130,11 @@ int Test_N_VConstrMaskLocal(N_Vector C, N_Vector X, N_Vector M,
 int Test_N_VMinQuotientLocal(N_Vector NUM, N_Vector DENOM,
                              sunindextype local_length, int myid);
 
+/* Single buffer reduction tests */
+int Test_N_VDotProdMultiLocal(N_Vector X, sunindextype local_length, int myid);
+int Test_N_VDotProdMultiAllReduce(N_Vector X, sunindextype local_length,
+                                  int myid);
+
 /* XBraid interface operations */
 int Test_N_VBufSize(N_Vector x, sunindextype local_length, int myid);
 int Test_N_VBufPack(N_Vector x, sunindextype local_length, int myid);
