@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -18,9 +18,10 @@
 #define _ARKLS_IMPL_H
 
 #include <arkode/arkode_ls.h>
+
 #include "arkode_impl.h"
 
-#ifdef __cplusplus  /* wrapper to enable C++ usage */
+#ifdef __cplusplus /* wrapper to enable C++ usage */
 extern "C" {
 #endif
 
@@ -34,33 +35,32 @@ extern "C" {
                on the nonlinear iteration is multiplied to get
                a tolerance on the linear iteration
   ---------------------------------------------------------------*/
-#define ARKLS_MSBJ   51
-#define ARKLS_EPLIN  RCONST(0.05)
-
+#define ARKLS_MSBJ  51
+#define ARKLS_EPLIN SUN_RCONST(0.05)
 
 /*---------------------------------------------------------------
   Types: ARKLsMemRec, ARKLsMem
 
   The type ARKLsMem is pointer to a ARKLsMemRec.
   ---------------------------------------------------------------*/
-typedef struct ARKLsMemRec {
-
+typedef struct ARKLsMemRec
+{
   /* Linear solver type information */
-  booleantype iterative;    /* is the solver iterative?    */
-  booleantype matrixbased;  /* is a matrix structure used? */
+  sunbooleantype iterative;   /* is the solver iterative?    */
+  sunbooleantype matrixbased; /* is a matrix structure used? */
 
   /* Jacobian construction & storage */
-  booleantype jacDQ;  /* SUNTRUE if using internal DQ Jacobian approx. */
-  ARKLsJacFn jac;     /* Jacobian routine to be called                 */
-  void *J_data;       /* user data is passed to jac                    */
-  booleantype jbad;   /* heuristic suggestion for pset                 */
+  sunbooleantype jacDQ; /* SUNTRUE if using internal DQ Jacobian approx. */
+  ARKLsJacFn jac;       /* Jacobian routine to be called                 */
+  void* J_data;         /* user data is passed to jac                    */
+  sunbooleantype jbad;  /* heuristic suggestion for pset                 */
 
   /* Matrix-based solver, scale solution to account for change in gamma */
-  booleantype scalesol;
+  sunbooleantype scalesol;
 
   /* Iterative solver tolerance */
-  realtype eplifac;   /* nonlinear -> linear tol scaling factor        */
-  realtype nrmfac;    /* integrator -> LS norm conversion factor       */
+  sunrealtype eplifac; /* nonlinear -> linear tol scaling factor        */
+  sunrealtype nrmfac;  /* integrator -> LS norm conversion factor       */
 
   /* Linear solver, matrix and vector objects/pointers */
   SUNLinearSolver LS; /* generic linear solver object                  */
@@ -72,19 +72,19 @@ typedef struct ARKLsMemRec {
   N_Vector fcur;      /* ptr to current fcur = fI(tcur, ycur)          */
 
   /* Statistics and associated parameters */
-  long int msbj;      /* max num steps between jac/pset calls         */
-  realtype tcur;      /* 'time' for current ARKLs solve               */
-  long int nje;       /* no. of calls to jac                          */
-  long int nfeDQ;     /* no. of calls to f due to DQ Jacobian or J*v
+  long int msbj;     /* max num steps between jac/pset calls         */
+  sunrealtype tcur;  /* 'time' for current ARKLs solve               */
+  long int nje;      /* no. of calls to jac                          */
+  long int nfeDQ;    /* no. of calls to f due to DQ Jacobian or J*v
                          approximations                               */
-  long int nstlj;     /* value of nst at the last jac/pset call       */
-  long int npe;       /* npe = total number of pset calls             */
-  long int nli;       /* nli = total number of linear iterations      */
-  long int nps;       /* nps = total number of psolve calls           */
-  long int ncfl;      /* ncfl = total number of convergence failures  */
-  long int njtsetup;  /* njtsetup = total number of calls to jtsetup  */
-  long int njtimes;   /* njtimes = total number of calls to jtimes    */
-  sunrealtype tnlj;   /* tnlj = t_n at last jac/pset call             */
+  long int nstlj;    /* value of nst at the last jac/pset call       */
+  long int npe;      /* npe = total number of pset calls             */
+  long int nli;      /* nli = total number of linear iterations      */
+  long int nps;      /* nps = total number of psolve calls           */
+  long int ncfl;     /* ncfl = total number of convergence failures  */
+  long int njtsetup; /* njtsetup = total number of calls to jtsetup  */
+  long int njtimes;  /* njtimes = total number of calls to jtimes    */
+  sunrealtype tnlj;  /* tnlj = t_n at last jac/pset call             */
 
   /* Preconditioner computation
     (a) user-provided:
@@ -96,7 +96,7 @@ typedef struct ARKLsMemRec {
   ARKLsPrecSetupFn pset;
   ARKLsPrecSolveFn psolve;
   int (*pfree)(ARKodeMem ark_mem);
-  void *P_data;
+  void* P_data;
 
   /* Jacobian times vector computation
     (a) jtimes function provided by the user:
@@ -105,12 +105,11 @@ typedef struct ARKLsMemRec {
     (b) internal jtimes
         - Jt_data == arkode_mem
         - jtimesDQ == SUNTRUE   */
-  booleantype jtimesDQ;
+  sunbooleantype jtimesDQ;
   ARKLsJacTimesSetupFn jtsetup;
   ARKLsJacTimesVecFn jtimes;
   ARKRhsFn Jt_f;
-  void *Jt_data;
-
+  void* Jt_data;
 
   /* Linear system setup function
    * (a) user-provided linsys function:
@@ -119,48 +118,47 @@ typedef struct ARKLsMemRec {
    * (b) internal linsys function:
    *     - user_linsys = SUNFALSE
    *     - A_data      = cvode_mem */
-  booleantype user_linsys;
+  sunbooleantype user_linsys;
   ARKLsLinSysFn linsys;
   void* A_data;
 
   int last_flag; /* last error flag returned by any function */
 
-} *ARKLsMem;
-
+}* ARKLsMem;
 
 /*---------------------------------------------------------------
   Types: ARKLsMassMemRec, ARKLsMassMem
 
   The type ARKLsMassMem is pointer to a ARKLsMassMemRec.
   ---------------------------------------------------------------*/
-typedef struct ARKLsMassMemRec {
-
+typedef struct ARKLsMassMemRec
+{
   /* Linear solver type information */
-  booleantype iterative;    /* is the solver iterative?    */
-  booleantype matrixbased;  /* is a matrix structure used? */
+  sunbooleantype iterative;   /* is the solver iterative?    */
+  sunbooleantype matrixbased; /* is a matrix structure used? */
 
   /* Mass matrix construction & storage */
-  ARKLsMassFn mass;   /* user-provided mass matrix routine to call   */
-  SUNMatrix M;        /* mass matrix structure                       */
-  SUNMatrix M_lu;     /* mass matrix structure for LU decomposition  */
-  void* M_data;       /* user data pointer */
+  ARKLsMassFn mass; /* user-provided mass matrix routine to call   */
+  SUNMatrix M;      /* mass matrix structure                       */
+  SUNMatrix M_lu;   /* mass matrix structure for LU decomposition  */
+  void* M_data;     /* user data pointer */
 
   /* Iterative solver tolerance */
-  realtype eplifac;   /* nonlinear -> linear tol scaling factor      */
-  realtype nrmfac;    /* integrator -> LS norm conversion factor     */
+  sunrealtype eplifac; /* nonlinear -> linear tol scaling factor      */
+  sunrealtype nrmfac;  /* integrator -> LS norm conversion factor     */
 
   /* Statistics and associated parameters */
-  booleantype time_dependent;  /* flag whether M depends on t        */
-  realtype    msetuptime;      /* "t" value at last msetup call      */
-  long int    nmsetups;        /* total # mass matrix-solver setups  */
-  long int    nmsolves;        /* total # mass matrix-solver solves  */
-  long int    nmtsetup;        /* total # calls to mtsetup           */
-  long int    nmtimes;         /* total # calls to mtimes            */
-  long int    nmvsetup;        /* total # calls to matvec setup      */
-  long int    npe;             /* total # pset calls                 */
-  long int    nli;             /* total # linear iterations          */
-  long int    nps;             /* total # psolve calls               */
-  long int    ncfl;            /* total # convergence failures       */
+  sunbooleantype time_dependent; /* flag whether M depends on t        */
+  sunrealtype msetuptime;        /* "t" value at last msetup call      */
+  long int nmsetups;             /* total # mass matrix-solver setups  */
+  long int nmsolves;             /* total # mass matrix-solver solves  */
+  long int nmtsetup;             /* total # calls to mtsetup           */
+  long int nmtimes;              /* total # calls to mtimes            */
+  long int nmvsetup;             /* total # calls to matvec setup      */
+  long int npe;                  /* total # pset calls                 */
+  long int nli;                  /* total # linear iterations          */
+  long int nps;                  /* total # psolve calls               */
+  long int ncfl;                 /* total # convergence failures       */
 
   /* Linear solver, matrix and vector objects/pointers */
   SUNLinearSolver LS; /* generic linear solver object                */
@@ -177,17 +175,16 @@ typedef struct ARKLsMassMemRec {
   ARKLsMassPrecSetupFn pset;
   ARKLsMassPrecSolveFn psolve;
   int (*pfree)(ARKodeMem ark_mem);
-  void *P_data;
+  void* P_data;
 
   /* Mass matrix times vector setup and product routines, data */
   ARKLsMassTimesSetupFn mtsetup;
   ARKLsMassTimesVecFn mtimes;
-  void *mt_data;
+  void* mt_data;
 
   int last_flag; /* last error flag returned by any function    */
 
-} *ARKLsMassMem;
-
+}* ARKLsMassMem;
 
 /*---------------------------------------------------------------
   Prototypes of internal functions
@@ -196,53 +193,50 @@ typedef struct ARKLsMassMemRec {
 /* Interface routines called by system SUNLinearSolver */
 int arkLsATimes(void* arkode_mem, N_Vector v, N_Vector z);
 int arkLsPSetup(void* arkode_mem);
-int arkLsPSolve(void* arkode_mem, N_Vector r, N_Vector z,
-                realtype tol, int lr);
+int arkLsPSolve(void* arkode_mem, N_Vector r, N_Vector z, sunrealtype tol,
+                int lr);
 
 /* Interface routines called by mass SUNLinearSolver */
 int arkLsMTimes(void* arkode_mem, N_Vector v, N_Vector z);
 int arkLsMPSetup(void* arkode_mem);
-int arkLsMPSolve(void* arkode_mem, N_Vector r, N_Vector z,
-                 realtype tol, int lr);
+int arkLsMPSolve(void* arkode_mem, N_Vector r, N_Vector z, sunrealtype tol,
+                 int lr);
 
 /* Difference quotient approximation for Jac times vector */
-int arkLsDQJtimes(N_Vector v, N_Vector Jv, realtype t,
-                  N_Vector y, N_Vector fy, void* data,
-                  N_Vector work);
+int arkLsDQJtimes(N_Vector v, N_Vector Jv, sunrealtype t, N_Vector y,
+                  N_Vector fy, void* data, N_Vector work);
 
 /* Difference-quotient Jacobian approximation routines */
-int arkLsDQJac(realtype t, N_Vector y, N_Vector fy,
-               SUNMatrix Jac, void* data, N_Vector tmp1,
-               N_Vector tmp2, N_Vector tmp3);
-int arkLsDenseDQJac(realtype t, N_Vector y, N_Vector fy,
-                    SUNMatrix Jac, ARKodeMem ark_mem,
-                    ARKLsMem arkls_mem, ARKRhsFn fi, N_Vector tmp1);
-int arkLsBandDQJac(realtype t, N_Vector y, N_Vector fy,
-                   SUNMatrix Jac, ARKodeMem ark_mem,
-                   ARKLsMem arkls_mem, ARKRhsFn fi,
+int arkLsDQJac(sunrealtype t, N_Vector y, N_Vector fy, SUNMatrix Jac,
+               void* data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3);
+int arkLsDenseDQJac(sunrealtype t, N_Vector y, N_Vector fy, SUNMatrix Jac,
+                    ARKodeMem ark_mem, ARKLsMem arkls_mem, ARKRhsFn fi,
+                    N_Vector tmp1);
+int arkLsBandDQJac(sunrealtype t, N_Vector y, N_Vector fy, SUNMatrix Jac,
+                   ARKodeMem ark_mem, ARKLsMem arkls_mem, ARKRhsFn fi,
                    N_Vector tmp1, N_Vector tmp2);
 
 /* Generic linit/lsetup/lsolve/lfree interface routines for ARKODE to call */
 int arkLsInitialize(void* arkode_mem);
 
-int arkLsSetup(void* arkode_mem, int convfail, realtype tpred,
-               N_Vector ypred, N_Vector fpred, booleantype* jcurPtr,
+int arkLsSetup(void* arkode_mem, int convfail, sunrealtype tpred,
+               N_Vector ypred, N_Vector fpred, sunbooleantype* jcurPtr,
                N_Vector vtemp1, N_Vector vtemp2, N_Vector vtemp3);
 
-int arkLsSolve(void* arkode_mem, N_Vector b, realtype tcur,
-               N_Vector ycur, N_Vector fcur, realtype eRnrm, int mnewt);
+int arkLsSolve(void* arkode_mem, N_Vector b, sunrealtype tcur, N_Vector ycur,
+               N_Vector fcur, sunrealtype eRnrm, int mnewt);
 
 int arkLsFree(void* arkode_mem);
 
 /* Generic minit/msetup/mmult/msolve/mfree routines for ARKODE to call */
 int arkLsMassInitialize(void* arkode_mem);
 
-int arkLsMassSetup(void* arkode_mem, realtype t, N_Vector vtemp1,
+int arkLsMassSetup(void* arkode_mem, sunrealtype t, N_Vector vtemp1,
                    N_Vector vtemp2, N_Vector vtemp3);
 
 int arkLsMassMult(void* arkode_mem, N_Vector v, N_Vector Mv);
 
-int arkLsMassSolve(void* arkode_mem, N_Vector b, realtype nlscoef);
+int arkLsMassSolve(void* arkode_mem, N_Vector b, sunrealtype nlscoef);
 
 int arkLsMassFree(void* arkode_mem);
 
@@ -251,39 +245,39 @@ int arkLsInitializeCounters(ARKLsMem arkls_mem);
 
 int arkLsInitializeMassCounters(ARKLsMassMem arkls_mem);
 
-int arkLs_AccessLMem(void* arkode_mem, const char* fname,
-                     ARKodeMem* ark_mem, ARKLsMem* arkls_mem);
+int arkLs_AccessLMem(void* arkode_mem, const char* fname, ARKodeMem* ark_mem,
+                     ARKLsMem* arkls_mem);
 
-int arkLs_AccessMassMem(void* arkode_mem, const char* fname,
-                        ARKodeMem* ark_mem, ARKLsMassMem* arkls_mem);
+int arkLs_AccessMassMem(void* arkode_mem, const char* fname, ARKodeMem* ark_mem,
+                        ARKLsMassMem* arkls_mem);
 
 /* Set/get routines called by time-stepper module */
 int arkLSSetLinearSolver(void* arkode_mem, SUNLinearSolver LS, SUNMatrix A);
 
-int arkLSSetMassLinearSolver(void* arkode_mem, SUNLinearSolver LS,
-                             SUNMatrix M, booleantype time_dep);
+int arkLSSetMassLinearSolver(void* arkode_mem, SUNLinearSolver LS, SUNMatrix M,
+                             sunbooleantype time_dep);
 
 int arkLSSetJacFn(void* arkode_mem, ARKLsJacFn jac);
 int arkLSSetMassFn(void* arkode_mem, ARKLsMassFn mass);
-int arkLSSetEpsLin(void* arkode_mem, realtype eplifac);
-int arkLSSetMassEpsLin(void* arkode_mem, realtype eplifac);
-int arkLSSetNormFactor(void* arkode_mem, realtype nrmfac);
-int arkLSSetMassNormFactor(void* arkode_mem, realtype nrmfac);
+int arkLSSetEpsLin(void* arkode_mem, sunrealtype eplifac);
+int arkLSSetMassEpsLin(void* arkode_mem, sunrealtype eplifac);
+int arkLSSetNormFactor(void* arkode_mem, sunrealtype nrmfac);
+int arkLSSetMassNormFactor(void* arkode_mem, sunrealtype nrmfac);
 int arkLSSetJacEvalFrequency(void* arkode_mem, long int msbj);
-int arkLSSetLinearSolutionScaling(void* arkode_mem, booleantype onoff);
+int arkLSSetLinearSolutionScaling(void* arkode_mem, sunbooleantype onoff);
 int arkLSSetPreconditioner(void* arkode_mem, ARKLsPrecSetupFn psetup,
                            ARKLsPrecSolveFn psolve);
 int arkLSSetMassPreconditioner(void* arkode_mem, ARKLsMassPrecSetupFn psetup,
                                ARKLsMassPrecSolveFn psolve);
 int arkLSSetJacTimes(void* arkode_mem, ARKLsJacTimesSetupFn jtsetup,
                      ARKLsJacTimesVecFn jtimes);
-int arkLSSetJacTimesRhsFn(void *arkode_mem, ARKRhsFn jtimesRhsFn);
+int arkLSSetJacTimesRhsFn(void* arkode_mem, ARKRhsFn jtimesRhsFn);
 int arkLSSetMassTimes(void* arkode_mem, ARKLsMassTimesSetupFn msetup,
                       ARKLsMassTimesVecFn mtimes, void* mtimes_data);
 int arkLSSetLinSysFn(void* arkode_mem, ARKLsLinSysFn linsys);
 
-int arkLSSetUserData(void *arkode_mem, void* user_data);
-int arkLSSetMassUserData(void *arkode_mem, void* user_data);
+int arkLSSetUserData(void* arkode_mem, void* user_data);
+int arkLSSetMassUserData(void* arkode_mem, void* user_data);
 
 int arkLSGetJac(void* arkode_mem, SUNMatrix* J);
 int arkLSGetJacTime(void* arkode_mem, sunrealtype* t_J);
@@ -303,14 +297,14 @@ int arkLSGetMassWorkSpace(void* arkode_mem, long int* lenrwMLS,
                           long int* leniwMLS);
 int arkLSGetNumMassSetups(void* arkode_mem, long int* nmsetups);
 int arkLSGetNumMassMult(void* arkode_mem, long int* nmvevals);
-int arkLSGetNumMassMatvecSetups(void *arkode_mem, long int *nmvsetups);
+int arkLSGetNumMassMatvecSetups(void* arkode_mem, long int* nmvsetups);
 int arkLSGetNumMassSolves(void* arkode_mem, long int* nmsolves);
 int arkLSGetNumMassPrecEvals(void* arkode_mem, long int* nmpevals);
 int arkLSGetNumMassPrecSolves(void* arkode_mem, long int* nmpsolves);
 int arkLSGetNumMassIters(void* arkode_mem, long int* nmiters);
 int arkLSGetNumMassConvFails(void* arkode_mem, long int* nmcfails);
 int arkLSGetNumMTSetups(void* arkode_mem, long int* nmtsetups);
-int arkLSGetCurrentMassMatrix(void* arkode_mem, SUNMatrix *M);
+int arkLSGetCurrentMassMatrix(void* arkode_mem, SUNMatrix* M);
 int arkLSGetLastMassFlag(void* arkode_mem, long int* flag);
 
 char* arkLSGetReturnFlagName(long int flag);
@@ -318,24 +312,34 @@ char* arkLSGetReturnFlagName(long int flag);
 /*---------------------------------------------------------------
   Error Messages
   ---------------------------------------------------------------*/
-#define MSG_LS_ARKMEM_NULL     "Integrator memory is NULL."
-#define MSG_LS_MEM_FAIL        "A memory request failed."
-#define MSG_LS_BAD_NVECTOR     "A required vector operation is not implemented."
-#define MSG_LS_BAD_LSTYPE      "Incompatible linear solver type."
-#define MSG_LS_LMEM_NULL       "Linear solver memory is NULL."
-#define MSG_LS_MASSMEM_NULL    "Mass matrix solver memory is NULL."
-#define MSG_LS_BAD_SIZES       "Illegal bandwidth parameter(s). Must have 0 <=  ml, mu <= N-1."
+#define MSG_LS_ARKMEM_NULL  "Integrator memory is NULL."
+#define MSG_LS_MEM_FAIL     "A memory request failed."
+#define MSG_LS_BAD_NVECTOR  "A required vector operation is not implemented."
+#define MSG_LS_BAD_LSTYPE   "Incompatible linear solver type."
+#define MSG_LS_LMEM_NULL    "Linear solver memory is NULL."
+#define MSG_LS_MASSMEM_NULL "Mass matrix solver memory is NULL."
+#define MSG_LS_BAD_SIZES \
+  "Illegal bandwidth parameter(s). Must have 0 <=  ml, mu <= N-1."
 
-#define MSG_LS_PSET_FAILED     "The preconditioner setup routine failed in an unrecoverable manner."
-#define MSG_LS_PSOLVE_FAILED   "The preconditioner solve routine failed in an unrecoverable manner."
-#define MSG_LS_JTSETUP_FAILED  "The Jacobian x vector setup routine failed in an unrecoverable manner."
-#define MSG_LS_JTIMES_FAILED   "The Jacobian x vector routine failed in an unrecoverable manner."
-#define MSG_LS_MTSETUP_FAILED  "The mass matrix x vector setup routine failed in an unrecoverable manner."
-#define MSG_LS_MTIMES_FAILED   "The mass matrix x vector routine failed in an unrecoverable manner."
+#define MSG_LS_PSET_FAILED \
+  "The preconditioner setup routine failed in an unrecoverable manner."
+#define MSG_LS_PSOLVE_FAILED \
+  "The preconditioner solve routine failed in an unrecoverable manner."
+#define MSG_LS_JTSETUP_FAILED \
+  "The Jacobian x vector setup routine failed in an unrecoverable manner."
+#define MSG_LS_JTIMES_FAILED \
+  "The Jacobian x vector routine failed in an unrecoverable manner."
+#define MSG_LS_MTSETUP_FAILED \
+  "The mass matrix x vector setup routine failed in an unrecoverable manner."
+#define MSG_LS_MTIMES_FAILED \
+  "The mass matrix x vector routine failed in an unrecoverable manner."
 
-#define MSG_LS_JACFUNC_FAILED  "The Jacobian routine failed in an unrecoverable manner."
-#define MSG_LS_MASSFUNC_FAILED "The mass matrix routine failed in an unrecoverable manner."
-#define MSG_LS_SUNMAT_FAILED   "A SUNMatrix routine failed in an unrecoverable manner."
+#define MSG_LS_JACFUNC_FAILED \
+  "The Jacobian routine failed in an unrecoverable manner."
+#define MSG_LS_MASSFUNC_FAILED \
+  "The mass matrix routine failed in an unrecoverable manner."
+#define MSG_LS_SUNMAT_FAILED \
+  "A SUNMatrix routine failed in an unrecoverable manner."
 
 #ifdef __cplusplus
 }
